==> openwebbeans-4.0.2-source-release.zip: openwebbeans-4.0.2/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.reservation.util;

import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

@RequestScoped
public class EntityManagerUtil
{
    private @PersistenceContext(unitName="reservation") EntityManager entityManager;
    
    public EntityManagerUtil()
    {
        
    }
    
    @Produces @RequestScoped @org.apache.webbeans.reservation.bindings.EntityManagerQualifier
    public EntityManager createEntityManager()
    {        
        return entityManager;
    }
    
    public void dispose(@Disposes @org.apache.webbeans.reservation.bindings.EntityManagerQualifier EntityManager entityManager)
    {
        entityManager.close();        
    }
    
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/samples/reservation/src/main/java/org/apache/webbeans/reservation/util/EntityManagerUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.reservation.util;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;
import jakarta.persistence.EntityManager;
import jakarta.persistence.EntityManagerFactory;
import jakarta.persistence.Persistence;

@RequestScoped
public class EntityManagerUtil
{
    private EntityManagerFactory emf;

    @PostConstruct
    void init()
    {
        emf = Persistence.createEntityManagerFactory("reservation");
    }
    
    @Produces
    @RequestScoped
    public EntityManager createEntityManager()
    {        
        return emf.createEntityManager();
    }
    
    public void dispose(@Disposes EntityManager entityManager)
    {
        entityManager.close();        
    }
    
}
